@@ -16,7 +16,7 @@ import requests
 import os
 import sys
 
-__version__ = "1.8.10"
+__version__ = "1.9.5"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -166,7 +166,7 @@ def up_to_date():
 
 def update():
     username = n_env.user
-    api_url = f"{n_env.hub_api}/hub/api"
+    api_url = f"{n_env.hub_base}/hub/api"
     r = requests.delete(
         f"{api_url}/users/{username}/server",
         headers={
