@@ -1,4 +1,5 @@
-from naas.types import (
+from .custom_papermill import execute_notebook
+from naas.ntypes import (
     t_notebook,
     t_scheduler,
     t_error,
@@ -14,21 +15,20 @@ from naas.types import (
     mime_list,
 )
 from nbconvert import HTMLExporter
-from sanic import response
 from .env_var import cpath, n_env
+from sanic import response
 import papermill as pm
-from .custom_papermill import execute_notebook
 import traceback
 import datetime
 import shutil
 import base64
+import pytz
 import json
 import time
 import bs4
 import csv
 import os
 import io
-import pytz
 
 kern_manager = None
 
@@ -236,6 +236,7 @@ class Notebooks:
                 input_path=file_filepath,
                 output_path=file_filepath_out,
                 progress_bar=False,
+                autosave_cell_every=0,
                 cwd=file_dirpath,
                 parameters=params,
                 kernel_manager_class=kern_manager,
@@ -247,6 +248,7 @@ class Notebooks:
                 input_path=file_filepath,
                 output_path=file_filepath_out,
                 progress_bar=False,
+                autosave_cell_every=0,
                 cwd=file_dirpath,
                 parameters=params,
             )
